%--------------------------------------------------------------------------
% File     : GRP133=SchroederNoIdem-1.SIZE : TPTP v1.2.0. Released v1.2.0.
% Domain   : Group Theory (Quasigroups)
% Problem  : (a.b).(b.a) = a, no idempotence
% Version  : [Slaney, 1993] axioms. 
% English  : Generate the multiplication table for the specified quasi-
%            group with SIZE elements.

% Refs     : Fujita M., Slaney J., Bennett F. (1993), Automatic Generation
%            of Some Results in Finite Algebra, Bajcsy R. (Ed), 
%            Proceedings of the 13th International Joint Conference on
%            Artificial Intelligence (Chambery, France, 1993), Morgan
%            Kaufman, San Mateo, USA, 52-57.
%          : Slaney J. (1993), Email to Geoff Sutcliffe.
%          : Slaney J., Fujita M., Stickel M. (1995), Automated Reasoning
%            and Exhaustive Search: Quasigroup Existence Problems,
%            Computers and Mathematics with Applications 29(2), 115-132.
% Source   : [Slaney, 1993]
% Names    : QG3-ni [Slaney, 1993]

% Status   : STATUS
% Syntax   : Number of clauses           : CLSS (NNHN non-Horn)(UNIT unit)
%            Number of literals          : LITS (EQLS equality)
%            Maximal clause size         : CLSZ
%            Number of predicate symbols : PRED (PROP propositional)
%            Number of function symbols  : FUNC (CNST constant)
%            Number of variables         : VARS (SGTN singleton)
%            Maximal term depth          : TMDP

% Comments : Slaney's [1993] axiomatization has been modified for this.
%          : Substitution axioms are not needed, as any positive equality
%            literals should resolve on negative ones directly.
%--------------------------------------------------------------------------
%----Include basic quasigroup code
:-tptp2X_include('Generators/GRP123-1.g').
%--------------------------------------------------------------------------
%----The status of this problem (including some open!)
'GRP133-1_status'(Size,unsatisfiable):-
    tptp2X_member(Size,[5]),
    !.

'GRP133-1_status'(Size,open):-
    tptp2X_member(Size,[12]),
    !.

'GRP133-1_status'(Size,satisfiable):-
    0 is Size mod 4,
    !.

'GRP133-1_status'(Size,satisfiable):-
    1 is Size mod 4,
    !.

'GRP133-1_status'(Size,unsatisfiable):-
    2 is Size mod 4,
    !.

'GRP133-1_status'(Size,unsatisfiable):-
    3 is Size mod 4,
    !.
%--------------------------------------------------------------------------
'GRP133-1'(Size,Clauses,Status):-
    integer(Size),
    'GRP123-1_qg_element_clauses'(Size,ElementClauses),
    'GRP123-1_standard_qg_clauses'(Size,product,StandardClauses,no),
    tptp2X_append(ElementClauses,StandardClauses,AxiomClauses),
    tptp2X_append(AxiomClauses,[
input_clause(qg3,theorem,
    [--product('X','Y','Z1'),
     --product('Y','X','Z2'),
     ++product('Z1','Z2','X')])],Clauses),
    'GRP133-1_status'(Size,Status).
%--------------------------------------------------------------------------
%----Provide information about the GRP133-1 generator
'GRP133-1_file_information'(generator,sizes(X,(X>=1)),sota(2)).
%--------------------------------------------------------------------------
