%--------------------------------------------------------------------------
% File     : MSC007=Pigeon-1.SIZE : TPTP v1.2.0. Released v1.0.0.
% Domain   : Miscellaneous
% Problem  : Cook pigeon-hole problem
% Version  : Theorem formulation : Propositional.
% English  : Suppose there are N holes and N+1 pigeons to put in the 
%            holes. Every pigeon is in a hole and no hole contains more 
%            than one pigeon. Prove that this is impossible. The size is 
%            the number of pigeons.

% Refs     : Cook S. and Reckhow R. (1979), The Relative Efficiency 
%            of Propositional Proof Systems, Journal of Symbolic Logic 44, 
%            36-50.
%          : Pelletier F.J. (1986), Seventy-Five Problems for Testing
%            Automatic Theorem Provers, Journal of Automated Reasoning
%            2(2), 191-216.
% Source   : [Pelletier, 1986]
% Names    : Pelletier 72 (Size 4) [Pelletier, 1986]
%          : pigeon.in (Size 4) [OTTER]

% Status   : STATUS
% Syntax   : Number of clauses           : CLSS (NNHN non-Horn)(UNIT unit)
%            Number of literals          : LITS (EQLS equality)
%            Maximal clause size         : CLSZ
%            Number of predicate symbols : PRED (PROP propositional)
%            Number of function symbols  : FUNC (CNST constant)
%            Number of variables         : VARS (SGTN singleton)
%            Maximal term depth          : TMDP

% Comments : For an N hole problem, the number of propositions 
%            is N^2 + N and the number of clauses is (N^3 + N^2)/2 + N+1. 
%            Thus the number of propositions increases quadratically and 
%            the number of clauses increases cubically.
%--------------------------------------------------------------------------
'MSC007-1_pigeon_somewhere_literals'([],_,[]).

'MSC007-1_pigeon_somewhere_literals'([FirstPigeon|RestOfPigeons],
NumberOfHoles,[FirstLiterals|RestOfPigeonSomewhereLiteralLists]):-
    concatenate_atoms([FirstPigeon,'_in_hole'],LiteralBase),
    generate_literals(1,NumberOfHoles,LiteralBase,_,FirstLiterals,_),
    'MSC007-1_pigeon_somewhere_literals'(RestOfPigeons,NumberOfHoles,
RestOfPigeonSomewhereLiteralLists).
%--------------------------------------------------------------------------
'MSC007-1_one_per_hole_clause'(NumberOfPigeons,NumberOfHoles,
input_clause(Name,theorem,[--Atom1,--Atom2])):-
    tptp2X_integer_in_range(1,NumberOfHoles,Hole),
    tptp2X_integer_in_range(1,NumberOfPigeons,Pigeon1),
    NextPigeon is Pigeon1 + 1,
    tptp2X_integer_in_range(NextPigeon,NumberOfPigeons,Pigeon2),
    concatenate_atoms([hole_,Hole,'_pigeons_',Pigeon1,'_and_',Pigeon2],
Name),
    concatenate_atoms([pigeon_,Pigeon1,'_in_hole_',Hole],Atom1),
    concatenate_atoms([pigeon_,Pigeon2,'_in_hole_',Hole],Atom2).
%--------------------------------------------------------------------------
'MSC007-1'(NumberOfPigeons,Clauses,unsatisfiable):-
    integer(NumberOfPigeons),
    NumberOfHoles is NumberOfPigeons - 1,
    generate_terms(1,NumberOfPigeons,pigeon,PigeonTerms),
    'MSC007-1_pigeon_somewhere_literals'(PigeonTerms,NumberOfHoles,
PigeonSomewhereLiteralLists),
    make_input_clauses(PigeonSomewhereLiteralLists,pigeon,1,theorem,
PigeonSomewhereClauses),
    findall(OnePerHoleClause,
        'MSC007-1_one_per_hole_clause'(NumberOfPigeons,NumberOfHoles,
OnePerHoleClause),OnePerHoleClauses),
    tptp2X_append(PigeonSomewhereClauses,OnePerHoleClauses,Clauses).
%--------------------------------------------------------------------------
%----Provide information about the MSC007-1 generator
'MSC007-1_file_information'(generator,sizes(X,(X>=2)),sota(5)).
%--------------------------------------------------------------------------
