%--------------------------------------------------------------------------
% File     : SYN001=Allways-1.SIZE : TPTP v1.2.0. Released v1.0.0.
% Domain   : Syntactic
% Problem  : All signed combinations of some propositions.
% Version  : 
% English  : Pelletier 2: A biconditional version of the 'most difficult' 
%            theorem proved by the new logic theorist.
%          : Pelletier 6: The Law of Excluded Middle: can be quite 
%            difficult for 'natural' systems.
%          : Pelletier 7: Expanded Law of Excluded Middle. The strategies 
%            of the original Logic Theorist cannot prove this.
%          : Pelletier 8: Pierce's Law. Unprovable by Logic Theorist, and 
%            tricky for 'natural' systems.
%          : Pelletier 11: A simple problem designed to see whether 
%            'natural' systems can do it efficiently (or whether they
%            incorrectly try to prove the -> each way).
%          : The size is the number of propositions.

% Refs     : Newell A. and Simon H. (1972), Human Problem Solving,
%            Prentice-Hall, Englewood Cliffs, NJ.
%          : Lawrence J.D., Starkey J.D. (1974), Experimental tests 
%            of resolution based theorem-proving strategies, Technical 
%            Report, Computer Science Department, Washington State 
%            University, Pullman, Washington.
%          : Wilson G.A. and Minker J. (1976), Resolution, Refinements, 
%            and Search Strategies: A Comparative Study, IEEE Transactions 
%            on Computers C-25(8), 782-801.
%          : Pelletier F.J. (1986), Seventy-Five Problems for Testing 
%            Automatic Theorem Provers, Journal of Automated Reasoning 
%            2(2), 191-216.
% Source   : [SPRFN], [Pelletier, 1986]
% Names    : ls5 (Size 2) [Lawrence & Starkey, 1974]
%          : ls5 (Size 2) [Wilson & Minker, 1976]
%          : Pelletier 2 (Size 1) [Pelletier, 1986]
%          : Pelletier 6 (Size 1) [Pelletier, 1986]
%          : Pelletier 7 (Size 1) [Pelletier, 1986]
%          : Pelletier 8 (Size 1) [Pelletier, 1986]
%          : Pelletier 9 (Size 2) [Pelletier, 1986]
%          : Pelletier 11 (Size 1) [Pelletier, 1986]
%          : Pelletier 12 (Size 3) [Pelletier, 1986]
%          : Pelletier 14 (Size 2) [Pelletier, 1986]

% Status   : STATUS
% Syntax   : Number of clauses           : CLSS (NNHN non-Horn)(UNIT unit)
%            Number of literals          : LITS (EQLS equality)
%            Maximal clause size         : CLSZ
%            Number of predicate symbols : PRED (PROP propositional)
%            Number of function symbols  : FUNC (CNST constant)
%            Number of variables         : VARS (SGTN singleton)
%            Maximal term depth          : TMDP

% Comments : 
%--------------------------------------------------------------------------
%----For each proposition, give it a sign to make a literal, and record
%----the sign letter
'SYN001-1_select_signs'([],[],[],[]).

%----Take positive literal
'SYN001-1_select_signs'([FirstPositiveLiteral|RestOfPositiveLiterals],
[_|RestOfNegativeLiterals],[FirstPositiveLiteral|RestOfLiterals],
[p|RestOfSignLetters]):-
    'SYN001-1_select_signs'(RestOfPositiveLiterals,RestOfNegativeLiterals,
RestOfLiterals,RestOfSignLetters).

%----Take negative literal
'SYN001-1_select_signs'([_|RestOfPositiveLiterals],[FirstNegativeLiteral|
RestOfNegativeLiterals],[FirstNegativeLiteral|RestOfLiterals],
[n|RestOfSignLetters]):-
    'SYN001-1_select_signs'(RestOfPositiveLiterals,RestOfNegativeLiterals,
RestOfLiterals,RestOfSignLetters).
%--------------------------------------------------------------------------
%----Make the clauses for all signed combination of Order propositions
'SYN001-1_generate_allways_clause'(PositiveLiterals,NegativeLiterals,
input_clause(Name,theorem,Literals)):-
    'SYN001-1_select_signs'(PositiveLiterals,NegativeLiterals,Literals,
NameList),
    concatenate_atoms(NameList,Name).
%--------------------------------------------------------------------------
'SYN001-1'(Size,Clauses,unsatisfiable):-
    integer(Size),
    generate_literals(1,Size,'p',_,PositiveLiterals,NegativeLiterals),
    findall(Clause,'SYN001-1_generate_allways_clause'(PositiveLiterals,
NegativeLiterals,Clause),Clauses).
%--------------------------------------------------------------------------
%----Provide information about the SYN001-1 generator
'SYN001-1_file_information'(generator,sizes(X,(X>=1)),sota(5)).
%--------------------------------------------------------------------------
