%--------------------------------------------------------------------------
% File     : COL043=StrongFxdPtBH-2 : TPTP v1.2.0. Released v1.2.0.
% Domain   : Combinatory Logic
% Problem  : Strong fixed point for B and H
% Version  : [Wos & McCune, 1988] (equality) axioms.
%            Theorem formulation : The fixed point is provided and 
%            checked.
% English  : The strong fixed point property holds for the set 
%            P consisting of the combinators B and H, where ((Bx)y)z 
%            = x(yz), ((Hx)y)z = ((xy)z)y.

% Refs     : Wos L., McCune W.W (1988), Challenge Problems Focusing 
%            on Equality and Combinatory Logic: Evaluating Automated 
%            Theorem-Proving Programs, Proceedings of the 9th 
%            International Conference on Automated Deduction (Argonne, IL, 
%            1988), (Lecture Notes in Computer Science, 310), 714-729.
%          : Wos L. (1993), The Kernel Strategy and its use for the Study 
%            of Combinatory Logic, Journal of Automated Reasoning 10(3), 
%            287-343.
% Source   : [Wos, 1993]
% Names    : Question 5 [Wos, 1993]

% Status   : unknown
% Syntax   : Number of clauses           :   10 (   0 non-Horn)(   4 unit)
%            Number of literals          :   17 (  15 equality)
%            Maximal clause size         :    3
%            Number of predicate symbols :    2 (   0 propositional)
%            Number of function symbols  :    5 (   3 constant)
%            Number of variables         :   21 (   0 singleton)
%            Maximal term depth          :   11

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(b_definition,axiom,
    [++equal(apply(apply(apply(b,X),Y),Z),apply(X,apply(Y,Z)))]).

input_clause(h_definition,axiom,
    [++equal(apply(apply(apply(h,X),Y),Z),apply(apply(apply(X,Y),Z),Y))]).

input_clause(apply_substitution1,axiom,
    [--equal(A,B),
     ++equal(apply(A,C),apply(B,C))]).

input_clause(apply_substitution2,axiom,
    [--equal(D,E),
     ++equal(apply(F,D),apply(F,E))]).

input_clause(f_substitution1,axiom,
    [--equal(G,H),
     ++equal(f(G),f(H))]).

input_clause(strong_fixed_point,axiom,
    [--equal(apply(Strong_fixed_point,fixed_pt),apply(fixed_pt,
apply(Strong_fixed_point,fixed_pt))),
     ++fixed_point(Strong_fixed_point)]).

input_clause(prove_strong_fixed_point,theorem,
    [--fixed_point(apply(apply(b,apply(apply(b,apply(apply(apply(h,
apply(apply(b,apply(b,h)),apply(b,b))),apply(apply(h,apply(b,h)),
apply(b,b))),h)),b)),b))]).
%--------------------------------------------------------------------------
