%--------------------------------------------------------------------------
% File     : GRP039=SubGI2Norm-2 : TPTP v1.2.0. Released v1.0.0.
% Domain   : Group Theory (Subgroups)
% Problem  : Subgroups of index 2 are normal
% Version  : [McCharen, et al., 1976] (equality) axioms :
%            Reduced & Augmented > Complete.
% English  : If O is a subgroup of G and there are exactly 2 cosets 
%            in G/O, then O is normal [that is, for all x in G and 
%            y in O, x*y*inverse(x) is back in O].

% Refs     : McCharen J.D., Overbeek R.A., Wos L.A. (1976), Problems and 
%            Experiments for and with Automated Theorem Proving Programs, 
%            IEEE Transactions on Computers C-25(8), 773-782.
%          : Lusk E., and Wos L. (1992), Benchmark Problems in Which 
%            Equality Plays the Major Role, In Kapur D. (Ed.), Proceedings 
%            of the 11th International Conference on Automated Deduction 
%            (Saratoga Springs, NY, 1992), (Lecture Notes in Artificial 
%            Intelligence 607), Springer-Verlag, New York, NY, 781-785.
% Source   : [ANL]
% Names    : NU2 [Lusk & Wos, 1992]

% Status   : unknown
% Syntax   : Number of clauses           :   22 (   2 non-Horn)(  10 unit)
%            Number of literals          :   40 (  26 equality)
%            Maximal clause size         :    4
%            Number of predicate symbols :    2 (   0 propositional)
%            Number of function symbols  :    8 (   5 constant)
%            Number of variables         :   37 (   0 singleton)
%            Maximal term depth          :    3

% Comments : Used to define a subgroup of index two is a theorem which 
%            says that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y} if & only if {O has index 2 in G}. This z is named 
%            by the skolem function i(x,y). Explanation: If O is of index 
%            two in G, then there are exactly two cosets, namely O and 
%            uO for some u not in O. If both of x and y are not in O, then 
%            they are in uO. But then xO=yO, which implies that there 
%            exists some z in O such that x*z=y. If the condition holds 
%            that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y}, then xO=yO for all x,y not in O, which implies that 
%            there are at most two cosets; and there must be at least two, 
%            namely O and xO, since x is not in O. Therefore O must 
%            be of index two.
%          : The redundant axiom that states that the identity element 
%            is in the subgroup, present in the [McCharen, et al., 1976] 
%            presentation, is omitted here.
%          : element_in_O2(A,B) is A^-1.B. The axioms with element_in_O2 
%            force index 2.
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%----Include the equality axioms for group theory in equality form 
include('Axioms/GRP004-0.ax').
%----Include the subgroup axioms in equality formulation 
include('Axioms/GRP004-1.ax').
%--------------------------------------------------------------------------
%----Redundant two axioms
input_clause(right_identity,axiom,
    [++equal(multiply(X,identity),X)]).

input_clause(right_inverse,axiom,
    [++equal(multiply(X,inverse(X)),identity)]).

%----Definition of a subgroup of index 2 
input_clause(an_element_in_O2,axiom,
    [++subgroup_member(X),
     ++subgroup_member(Y),
     ++subgroup_member(element_in_O2(X,Y))]).

input_clause(property_of_O2,axiom,
    [++subgroup_member(X),
     ++subgroup_member(Y),
     ++equal(multiply(X,element_in_O2(X,Y)),Y)]).

input_clause(element_in_O2_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(element_in_O2(A,C),element_in_O2(B,C))]).

input_clause(element_in_O2_substitutivity2,axiom,
    [--equal(D,E),
     ++equal(element_in_O2(F,D),element_in_O2(F,E))]).

%----Denial of theorem 
input_clause(b_in_O2,hypothesis,
    [++subgroup_member(b)]).

input_clause(b_times_a_inverse_is_c,hypothesis,
    [++equal(multiply(b,inverse(a)),c)]).

input_clause(a_times_c_is_d,hypothesis,
    [++equal(multiply(a,c),d)]).

input_clause(prove_d_in_O2,hypothesis,
    [--subgroup_member(d)]).
%--------------------------------------------------------------------------
