%--------------------------------------------------------------------------
% File     : GRP114=PosTimesNeg-1 : TPTP v1.2.0. Released v1.2.0.
% Domain   : Group Theory
% Problem  : Product of positive and negative parts of X equals X
% Version  : [McCharen, et al., 1976] (equality) axioms : Augmented.
% English  : Prove that for each element X in a group, X is equal to the 
%            product of its positive part (the union with the identity) 
%            and its negative part (the intersection with the identity).

% Refs     : Wos L. (1994), Challenge in Group Theory, AAR Newsletter 26, 
%            3-5.
% Source   : [Wos, 1994]
% Names    : - [Wos, 1994]

% Status   : unknown
% Syntax   : Number of clauses           :   33 (   0 non-Horn)(  22 unit)
%            Number of literals          :   45 (  45 equality)
%            Maximal clause size         :    3
%            Number of predicate symbols :    1 (   0 propositional)
%            Number of function symbols  :    8 (   2 constant)
%            Number of variables         :   68 (   2 singleton)
%            Maximal term depth          :    3

% Comments : I know some of the axioms are redundant, and have put 
%            comments to that effect. However, I don't know how to make 
%            a complete standard axiomatisation for the union and 
%            intersection axioms.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include the axioms for named groups 
include('Axioms/GRP004-0.ax').
%--------------------------------------------------------------------------
%----This axiom is a lemma 
input_clause(inverse_of_identity,axiom,
    [++equal(inverse(identity),identity)]).

%----This axiom is a lemma 
input_clause(inverse_involution,axiom,
    [++equal(inverse(inverse(X)),X)]).

%----This axiom is a lemma 
input_clause(inverse_product_lemma,axiom,
    [++equal(inverse(multiply(X,Y)),multiply(inverse(Y),inverse(X)))]).

input_clause(intersection_idempotent,axiom,
    [++equal(intersection(X,X),X)]).

input_clause(union_idempotent,axiom,
    [++equal(union(X,X),X)]).

input_clause(intersection_commutative,axiom,
    [++equal(intersection(X,Y),intersection(Y,X))]).

input_clause(union_commutative,axiom,
    [++equal(union(X,Y),union(Y,X))]).

input_clause(intersection_associative,axiom,
    [++equal(intersection(X,intersection(Y,Z)),intersection(
intersection(X,Y),Z))]).

input_clause(union_associative,axiom,
    [++equal(union(X,union(Y,Z)),union(union(X,Y),Z))]).

input_clause(union_intersection_absorbtion,axiom,
    [++equal(union(intersection(X,Y),Y),Y)]).

input_clause(intersection_union_absorbtion,axiom,
    [++equal(intersection(union(X,Y),Y),Y)]).

input_clause(multiply_union1,axiom,
    [++equal(multiply(X,union(Y,Z)),union(multiply(X,Y),multiply(X,Z)))]).

input_clause(multiply_intersection1,axiom,
    [++equal(multiply(X,intersection(Y,Z)),intersection(multiply(X,Y),
multiply(X,Z)))]).

input_clause(multiply_union2,axiom,
    [++equal(multiply(union(Y,Z),X),union(multiply(Y,X),multiply(Z,X)))]).

input_clause(multiply_intersection2,axiom,
    [++equal(multiply(intersection(Y,Z),X),intersection(multiply(Y,X),
multiply(Z,X)))]).

input_clause(positive_part,axiom,
    [++equal(positive_part(X),union(X,identity))]).

input_clause(negative_part,axiom,
    [++equal(negative_part(X),intersection(X,identity))]).

%----Substitution axioms
input_clause(intersection_substitution1,axiom,
    [--equal(A,B),
     ++equal(intersection(A,C),intersection(B,C))]).

input_clause(intersection_substitution2,axiom,
    [--equal(D,E),
     ++equal(intersection(F,D),intersection(F,E))]).

input_clause(negative_part_substitution1,axiom,
    [--equal(G,H),
     ++equal(negative_part(G),negative_part(H))]).

input_clause(positive_part_substitution1,axiom,
    [--equal(I,J),
     ++equal(positive_part(I),positive_part(J))]).

input_clause(union_substitution1,axiom,
    [--equal(K,L),
     ++equal(union(K,M),union(L,M))]).

input_clause(union_substitution2,axiom,
    [--equal(N,O),
     ++equal(union(P,N),union(P,O))]).

input_clause(prove_product,theorem,
    [--equal(multiply(positive_part(a),negative_part(a)),a)]).
%--------------------------------------------------------------------------
