%--------------------------------------------------------------------------
% File     : GRP123=321COILS-4.003 : TPTP v1.2.0. Bugfixed v1.2.1.
% Domain   : Group Theory (Quasigroups)
% Problem  : (3,2,1) conjugate orthogonality
% Version  : [Slaney, 1993] axioms : Augmented. 
% English  : If ab=xy and a*b = x*y then a=x and b=y, where c*b=a iff ab=c.
%            Generate the multiplication table for the specified quasi-
%            group with 3 elements.

% Refs     : Fujita M., Slaney J., Bennett F. (1993), Automatic Generation
%            of Some Results in Finite Algebra, Bajcsy R. (Ed), 
%            Proceedings of the 13th International Joint Conference on
%            Artificial Intelligence (Chambery, France, 1993), Morgan
%            Kaufman, San Mateo, USA, 52-57.
%          : Slaney J. (1993), Email to Geoff Sutcliffe.
%          : Zhang H. (1994) Email to Geoff Sutcliffe.
%          : Slaney J., Fujita M., Stickel M. (1995), Automated Reasoning
%            and Exhaustive Search: Quasigroup Existence Problems,
%            Computers and Mathematics with Applications 29(2), 115-132.
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Syntax   : Number of clauses           :   18 (   3 non-Horn)(  10 unit)
%            Number of literals          :   44 (  11 equality)
%            Maximal clause size         :    5
%            Number of predicate symbols :    3 (   0 propositional)
%            Number of function symbols  :    3 (   3 constant)
%            Number of variables         :   31 (   0 singleton)
%            Maximal term depth          :    1

% Comments : Slaney's [1993] axiomatization has been modified for this.
%          : Substitution axioms are not needed, as any positive equality
%            literals should resolve on negative ones directly.
%          : Zhang [Zhang, 1994] has pointed out that either one of qg1_1
%            or qg1_2 may be used, as each implies the other in this
%            scenario, with the help of cancellation. The dependence
%            cannot be proved, so both have been left in here.
%          : Version 4 has surjectivity and rotation
%          : tptp2X: -ftptp -s3 GRP123-4.g
% Bugfixes : v1.2.1 - Clauses row_surjectivity and column_surjectivity fixed.
%--------------------------------------------------------------------------
input_clause(row_surjectivity,axiom,
    [--group_element(X),
     --group_element(Y),
     ++product(e_1,X,Y),
     ++product(e_2,X,Y),
     ++product(e_3,X,Y)]).

input_clause(column_surjectivity,axiom,
    [--group_element(X),
     --group_element(Y),
     ++product(X,e_1,Y),
     ++product(X,e_2,Y),
     ++product(X,e_3,Y)]).

input_clause(element_1,axiom,
    [++group_element(e_1)]).

input_clause(element_2,axiom,
    [++group_element(e_2)]).

input_clause(element_3,axiom,
    [++group_element(e_3)]).

input_clause(e_1_is_not_e_2,axiom,
    [--equal(e_1,e_2)]).

input_clause(e_1_is_not_e_3,axiom,
    [--equal(e_1,e_3)]).

input_clause(e_2_is_not_e_1,axiom,
    [--equal(e_2,e_1)]).

input_clause(e_2_is_not_e_3,axiom,
    [--equal(e_2,e_3)]).

input_clause(e_3_is_not_e_1,axiom,
    [--equal(e_3,e_1)]).

input_clause(e_3_is_not_e_2,axiom,
    [--equal(e_3,e_2)]).

input_clause(product_total_function1,axiom,
    [--group_element(X),
     --group_element(Y),
     ++product(X,Y,e_1),
     ++product(X,Y,e_2),
     ++product(X,Y,e_3)]).

input_clause(product_total_function2,axiom,
    [--product(X,Y,W),
     --product(X,Y,Z),
     ++equal(W,Z)]).

input_clause(product_right_cancellation,axiom,
    [--product(X,W,Y),
     --product(X,Z,Y),
     ++equal(W,Z)]).

input_clause(product_left_cancellation,axiom,
    [--product(W,Y,X),
     --product(Z,Y,X),
     ++equal(W,Z)]).

input_clause(product_idempotence,axiom,
    [++product(X,X,X)]).

input_clause(qg1_1,theorem,
    [--product(X1,Y1,Z1),
     --product(X2,Y2,Z1),
     --product(Z2,Y1,X1),
     --product(Z2,Y2,X2),
     ++equal(X1,X2)]).

input_clause(qg1_2,theorem,
    [--product(X1,Y1,Z1),
     --product(X2,Y2,Z1),
     --product(Z2,Y1,X1),
     --product(Z2,Y2,X2),
     ++equal(Y1,Y2)]).
%--------------------------------------------------------------------------
