%--------------------------------------------------------------------------
% File     : GRP123=321COILS-6.003 : TPTP v1.2.0. Released v1.2.0.
% Domain   : Group Theory (Quasigroups)
% Problem  : (3,2,1) conjugate orthogonality
% Version  : [Slaney, 1993] axioms. 
%            Theorem formulation : Uses a second group.
% English  : If ab=xy and a*b = x*y then a=x and b=y, where c*b=a iff ab=c
%            Generate the multiplication table for the specified quasi-
%            group with 3 elements.

% Refs     : Fujita M., Slaney J., Bennett F. (1993), Automatic Generation
%            of Some Results in Finite Algebra, Bajcsy R. (Ed), 
%            Proceedings of the 13th International Joint Conference on
%            Artificial Intelligence (Chambery, France, 1993), Morgan
%            Kaufman, San Mateo, USA, 52-57.
%          : Slaney J. (1993), Email to Geoff Sutcliffe.
%          : Slaney J., Fujita M., Stickel M. (1995), Automated Reasoning
%            and Exhaustive Search: Quasigroup Existence Problems,
%            Computers and Mathematics with Applications 29(2), 115-132.
% Source   : [Slaney, 1993]
% Names    : QG1a [Slaney, 1993]

% Status   : unsatisfiable
% Syntax   : Number of clauses           :   20 (   2 non-Horn)(  11 unit)
%            Number of literals          :   42 (  12 equality)
%            Maximal clause size         :    5
%            Number of predicate symbols :    4 (   0 propositional)
%            Number of function symbols  :    3 (   3 constant)
%            Number of variables         :   34 (   0 singleton)
%            Maximal term depth          :    1

% Comments : Slaney's [1993] axiomatization has been modified for this.
%          : Substitution axioms are not needed, as any positive equality
%            literals should resolve on negative ones directly.
%          : tptp2X: -ftptp -s3 GRP123-6.g
%--------------------------------------------------------------------------
input_clause(element_1,axiom,
    [++group_element(e_1)]).

input_clause(element_2,axiom,
    [++group_element(e_2)]).

input_clause(element_3,axiom,
    [++group_element(e_3)]).

input_clause(e_1_is_not_e_2,axiom,
    [--equal(e_1,e_2)]).

input_clause(e_1_is_not_e_3,axiom,
    [--equal(e_1,e_3)]).

input_clause(e_2_is_not_e_1,axiom,
    [--equal(e_2,e_1)]).

input_clause(e_2_is_not_e_3,axiom,
    [--equal(e_2,e_3)]).

input_clause(e_3_is_not_e_1,axiom,
    [--equal(e_3,e_1)]).

input_clause(e_3_is_not_e_2,axiom,
    [--equal(e_3,e_2)]).

input_clause(product1_total_function1,axiom,
    [--group_element(X),
     --group_element(Y),
     ++product1(X,Y,e_1),
     ++product1(X,Y,e_2),
     ++product1(X,Y,e_3)]).

input_clause(product1_total_function2,axiom,
    [--product1(X,Y,W),
     --product1(X,Y,Z),
     ++equal(W,Z)]).

input_clause(product1_right_cancellation,axiom,
    [--product1(X,W,Y),
     --product1(X,Z,Y),
     ++equal(W,Z)]).

input_clause(product1_left_cancellation,axiom,
    [--product1(W,Y,X),
     --product1(Z,Y,X),
     ++equal(W,Z)]).

input_clause(product1_idempotence,axiom,
    [++product1(X,X,X)]).

input_clause(product2_total_function1,axiom,
    [--group_element(X),
     --group_element(Y),
     ++product2(X,Y,e_1),
     ++product2(X,Y,e_2),
     ++product2(X,Y,e_3)]).

input_clause(product2_total_function2,axiom,
    [--product2(X,Y,W),
     --product2(X,Y,Z),
     ++equal(W,Z)]).

input_clause(product2_right_cancellation,axiom,
    [--product2(X,W,Y),
     --product2(X,Z,Y),
     ++equal(W,Z)]).

input_clause(product2_left_cancellation,axiom,
    [--product2(W,Y,X),
     --product2(Z,Y,X),
     ++equal(W,Z)]).

input_clause(product2_idempotence,axiom,
    [++product2(X,X,X)]).

input_clause(qg1a,theorem,
    [--product1(X,Y,Z1),
     --product1(Z1,Y,Z2),
     ++product2(Z2,X,Y)]).
%--------------------------------------------------------------------------
