%--------------------------------------------------------------------------
% File     : GRP167=ProdPosNeg-1 : TPTP v1.2.0. Released v1.2.0.
% Domain   : Group Theory (Lattice Ordered)
% Problem  : Product of positive and negative parts
% Version  : [Fuchs, 1994] (equality) axioms.
% English  : Each element in a lattice ordered group can be stated as a
%            product of it's positive and it's negative part.

% Refs     : Fuchs M. (1994), The Application of Goal-Oriented Heuristics
%            for Proving Equational Theorems via the Unfailing Knuth-Bendix
%            Completion Procedure. A Case Study: Lattice Ordered Groups,
%            SEKI-Report SR-94-02, University of Kaiserslautern,
%            Kaiserslautern, Germany.
%          : Schulz S. (1995), Explanation Based Learning for Distributed
%            Equational Deduction, Diploma Thesis, University of
%            Kaiserslautern, Kaiserslautern, Germany.
%          : Dahn B.I. (1995), Email to Geoff Sutcliffe.
% Source   : [TPTP]
% Names    : 

% Status   : unknown
% Syntax   : Number of clauses           :   34 (   0 non-Horn)(  21 unit)
%            Number of literals          :   48 (  48 equality)
%            Maximal clause size         :    3
%            Number of predicate symbols :    1 (   0 propositional)
%            Number of function symbols  :    8 (   2 constant)
%            Number of variables         :   77 (   2 singleton)
%            Maximal term depth          :    3

% Comments : ORDERING LPO inverse > greatest_lower_bound >
%            least_upper_bound > product > negative_part > positive_part > 
%            identity > a
%          : This is a standardized version of the problem that appears in
%            [Schulz, 1995].
%          : [Dahn, 1995] says "This is crucial for reducing some problems 
%            on arbitrary elements to problems on positive elements. The 
%            proof is relatively difficult. It is non-obvious to humans 
%            since the standard tactics (unfold definitions - use 
%            distributivity - simplify) is not useful."
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include equality group theory axioms 
include('Axioms/GRP004-0.ax').
%----Include Lattice ordered group (equality) axioms
include('Axioms/GRP004-2.ax').
%--------------------------------------------------------------------------
input_clause(negative_part_substitution_1,axiom,
    [--equal(A,B),
     ++equal(negative_part(A),negative_part(B))]).

input_clause(positive_part_substitution_1,axiom,
    [--equal(A,B),
     ++equal(positive_part(A),positive_part(B))]).

input_clause(lat4_1,hypothesis,
    [++equal(positive_part(X),least_upper_bound(X,identity))]).

input_clause(lat4_2,hypothesis,
    [++equal(negative_part(X),greatest_lower_bound(X,identity))]).

input_clause(lat4_3,hypothesis,
    [++equal(least_upper_bound(X,greatest_lower_bound(Y,Z)),
greatest_lower_bound(least_upper_bound(X,Y),least_upper_bound(X,Z)))]).

input_clause(lat4_4,hypothesis,
    [++equal(greatest_lower_bound(X,least_upper_bound(Y,Z)),
least_upper_bound(greatest_lower_bound(X,Y),greatest_lower_bound(X,Z)))]).

input_clause(prove_lat4,theorem,
    [--equal(a,multiply(positive_part(a),negative_part(a)))]).
%--------------------------------------------------------------------------
