%--------------------------------------------------------------------------
% File     : MSC007=Pigeon-2.002 : TPTP v1.2.0. Released v1.0.0.
% Domain   : Miscellaneous
% Problem  : Cook pigeon-hole problem
% Version  : 
% English  : Suppose there are N holes and N+1 pigeons to put in the 
%            holes. Every pigeon is in a hole and no hole contains more 
%            than one pigeon. Prove that this is impossible. The size is 
%            the number of pigeons.

% Refs     : Cook S. and Reckhow R. (1979), The Relative Efficiency 
%            of Propositional Proof Systems, Journal of Symbolic Logic 44, 
%            36-50.
%          : Pelletier F.J. (1986), Seventy-Five Problems for Testing
%            Automatic Theorem Provers, Journal of Automated Reasoning
%            2(2), 191-216.
%          : Pelletier F.J. (1988), Errata, Journal of Automated
%            Reasoning 4(2), 235-236.
% Source   : [Pelletier, 1986]
% Names    : Pelletier 73 (Size 4) [Pelletier, 1986]

% Status   : unsatisfiable
% Syntax   : Number of clauses           :   16 (   0 non-Horn)(   5 unit)
%            Number of literals          :   36 (  15 equality)
%            Maximal clause size         :    6
%            Number of predicate symbols :    4 (   0 propositional)
%            Number of function symbols  :    4 (   3 constant)
%            Number of variables         :   24 (   0 singleton)
%            Maximal term depth          :    2

% Comments : This problem is incorrect in [Pelletier, 1986] and is
%            corrected in [Pelletier, 1988].
%          : tptp2X: -ftptp -s2 MSC007-2.g
%--------------------------------------------------------------------------
input_clause(reflexivity,axiom,
    [++equal(X,X)]).

input_clause(symmetry,axiom,
    [--equal(X,Y),
     ++equal(Y,X)]).

input_clause(transitivity,axiom,
    [--equal(X,Y),
     --equal(Y,Z),
     ++equal(X,Z)]).

input_clause(pigeon_substitutivity1,axiom,
    [--equal(X,Y),
     --pigeon(X),
     ++pigeon(Y)]).

input_clause(hole_of_substitutivity1,axiom,
    [--equal(X,Y),
     ++equal(hole_of(X),hole_of(Y))]).

input_clause(hole_substitutivity1,axiom,
    [--equal(X,Y),
     --hole(X),
     ++hole(Y)]).

input_clause(in_substitutivity1,axiom,
    [--equal(X,Y),
     --in(X,Z),
     ++in(Y,Z)]).

input_clause(in_substitutivity2,axiom,
    [--equal(X,Y),
     --in(Z,X),
     ++in(Z,Y)]).

input_clause(pigeon_1,axiom,
    [++pigeon(pigeon_1)]).

input_clause(pigeon_2,axiom,
    [++pigeon(pigeon_2)]).

input_clause(pigeon_1_is_not_pigeon_2,axiom,
    [--equal(pigeon_1,pigeon_2)]).

input_clause(hole_1,axiom,
    [++hole(hole_1)]).

input_clause(all_holes,axiom,
    [--hole(Hole),
     ++equal(Hole,hole_1)]).

input_clause(each_pigeons_hole1,axiom,
    [--pigeon(X),
     ++hole(hole_of(X))]).

input_clause(each_pigeons_hole2,axiom,
    [--pigeon(X),
     ++in(X,hole_of(X))]).

input_clause(only_one_per_hole,theorem,
    [--hole(Hole),
     --pigeon(Pigeon1),
     --pigeon(Pigeon2),
     --in(Pigeon1,Hole),
     --in(Pigeon2,Hole),
     ++equal(Pigeon1,Pigeon2)]).
%--------------------------------------------------------------------------
