%--------------------------------------------------------------------------
% File     : SYN001=Allways-1.005 : TPTP v1.2.0. Released v1.0.0.
% Domain   : Syntactic
% Problem  : All signed combinations of some propositions.
% Version  : 
% English  : Pelletier 2: A biconditional version of the 'most difficult' 
%            theorem proved by the new logic theorist.
%          : Pelletier 6: The Law of Excluded Middle: can be quite 
%            difficult for 'natural' systems.
%          : Pelletier 7: Expanded Law of Excluded Middle. The strategies 
%            of the original Logic Theorist cannot prove this.
%          : Pelletier 8: Pierce's Law. Unprovable by Logic Theorist, and 
%            tricky for 'natural' systems.
%          : Pelletier 11: A simple problem designed to see whether 
%            'natural' systems can do it efficiently (or whether they
%            incorrectly try to prove the -> each way).
%          : The size is the number of propositions.

% Refs     : Newell A. and Simon H. (1972), Human Problem Solving,
%            Prentice-Hall, Englewood Cliffs, NJ.
%          : Lawrence J.D., Starkey J.D. (1974), Experimental tests 
%            of resolution based theorem-proving strategies, Technical 
%            Report, Computer Science Department, Washington State 
%            University, Pullman, Washington.
%          : Wilson G.A. and Minker J. (1976), Resolution, Refinements, 
%            and Search Strategies: A Comparative Study, IEEE Transactions 
%            on Computers C-25(8), 782-801.
%          : Pelletier F.J. (1986), Seventy-Five Problems for Testing 
%            Automatic Theorem Provers, Journal of Automated Reasoning 
%            2(2), 191-216.
% Source   : [SPRFN], [Pelletier, 1986]
% Names    : ls5 (Size 2) [Lawrence & Starkey, 1974]
%          : ls5 (Size 2) [Wilson & Minker, 1976]
%          : Pelletier 2 (Size 1) [Pelletier, 1986]
%          : Pelletier 6 (Size 1) [Pelletier, 1986]
%          : Pelletier 7 (Size 1) [Pelletier, 1986]
%          : Pelletier 8 (Size 1) [Pelletier, 1986]
%          : Pelletier 9 (Size 2) [Pelletier, 1986]
%          : Pelletier 11 (Size 1) [Pelletier, 1986]
%          : Pelletier 12 (Size 3) [Pelletier, 1986]
%          : Pelletier 14 (Size 2) [Pelletier, 1986]

% Status   : unsatisfiable
% Syntax   : Number of clauses           :   32 (  26 non-Horn)(   0 unit)
%            Number of literals          :  160 (   0 equality)
%            Maximal clause size         :    5
%            Number of predicate symbols :    5 (   5 propositional)
%            Number of function symbols  :    0 (   0 constant)
%            Number of variables         :    0 (   0 singleton)
%            Maximal term depth          :    0

% Comments : 
%          : tptp2X: -ftptp -s5 SYN001-1.g
%--------------------------------------------------------------------------
input_clause(ppppp,theorem,
    [++p_1,++p_2,++p_3,++p_4,++p_5]).

input_clause(ppppn,theorem,
    [++p_1,++p_2,++p_3,++p_4,--p_5]).

input_clause(pppnp,theorem,
    [++p_1,++p_2,++p_3,--p_4,++p_5]).

input_clause(pppnn,theorem,
    [++p_1,++p_2,++p_3,--p_4,--p_5]).

input_clause(ppnpp,theorem,
    [++p_1,++p_2,--p_3,++p_4,++p_5]).

input_clause(ppnpn,theorem,
    [++p_1,++p_2,--p_3,++p_4,--p_5]).

input_clause(ppnnp,theorem,
    [++p_1,++p_2,--p_3,--p_4,++p_5]).

input_clause(ppnnn,theorem,
    [++p_1,++p_2,--p_3,--p_4,--p_5]).

input_clause(pnppp,theorem,
    [++p_1,--p_2,++p_3,++p_4,++p_5]).

input_clause(pnppn,theorem,
    [++p_1,--p_2,++p_3,++p_4,--p_5]).

input_clause(pnpnp,theorem,
    [++p_1,--p_2,++p_3,--p_4,++p_5]).

input_clause(pnpnn,theorem,
    [++p_1,--p_2,++p_3,--p_4,--p_5]).

input_clause(pnnpp,theorem,
    [++p_1,--p_2,--p_3,++p_4,++p_5]).

input_clause(pnnpn,theorem,
    [++p_1,--p_2,--p_3,++p_4,--p_5]).

input_clause(pnnnp,theorem,
    [++p_1,--p_2,--p_3,--p_4,++p_5]).

input_clause(pnnnn,theorem,
    [++p_1,--p_2,--p_3,--p_4,--p_5]).

input_clause(npppp,theorem,
    [--p_1,++p_2,++p_3,++p_4,++p_5]).

input_clause(npppn,theorem,
    [--p_1,++p_2,++p_3,++p_4,--p_5]).

input_clause(nppnp,theorem,
    [--p_1,++p_2,++p_3,--p_4,++p_5]).

input_clause(nppnn,theorem,
    [--p_1,++p_2,++p_3,--p_4,--p_5]).

input_clause(npnpp,theorem,
    [--p_1,++p_2,--p_3,++p_4,++p_5]).

input_clause(npnpn,theorem,
    [--p_1,++p_2,--p_3,++p_4,--p_5]).

input_clause(npnnp,theorem,
    [--p_1,++p_2,--p_3,--p_4,++p_5]).

input_clause(npnnn,theorem,
    [--p_1,++p_2,--p_3,--p_4,--p_5]).

input_clause(nnppp,theorem,
    [--p_1,--p_2,++p_3,++p_4,++p_5]).

input_clause(nnppn,theorem,
    [--p_1,--p_2,++p_3,++p_4,--p_5]).

input_clause(nnpnp,theorem,
    [--p_1,--p_2,++p_3,--p_4,++p_5]).

input_clause(nnpnn,theorem,
    [--p_1,--p_2,++p_3,--p_4,--p_5]).

input_clause(nnnpp,theorem,
    [--p_1,--p_2,--p_3,++p_4,++p_5]).

input_clause(nnnpn,theorem,
    [--p_1,--p_2,--p_3,++p_4,--p_5]).

input_clause(nnnnp,theorem,
    [--p_1,--p_2,--p_3,--p_4,++p_5]).

input_clause(nnnnn,theorem,
    [--p_1,--p_2,--p_3,--p_4,--p_5]).
%--------------------------------------------------------------------------
